//-----------------------------------------------------------------------------
// Nimbb
//   Gadget for Windows Vista Sidebar
//-----------------------------------------------------------------------------
// Desc:    This gadget allows to record short videos using a webcam. It uses 
//          the Nimbb Player technology from nimbb.com and requires Adobe
//          Flash Player.  All videos are stored on nimbb.com server.
// Author:  D2Soft Technologies Inc. (c) 2008-2009  All rights reserved.
// Site:    http://nimbb.com/
// Created: November 14th, 2008
// Updated: January 27th, 2009
// Legal:   You are free to use this file and distribute it without 
//          modifications.
//-----------------------------------------------------------------------------


//------------------------------------------------------------
// Private variables.
//------------------------------------------------------------
var _GadgetDocument = System.Gadget.document;
var _Guid = "";
var _Initializing = true;
var SHARE_URL = "http://nimbb.com/Share/[GUID]";

//------------------------------------------------------------
// OnEvent_Load()
// Desc: Gadget initialization.
//------------------------------------------------------------
function OnEvent_Load()
{
    // Specify the Flyout root.
    System.Gadget.Flyout.file = "record.htm";

    // Set handlers.
    System.Gadget.onUndock = OnEvent_UndockedState;
    System.Gadget.onDock = OnEvent_DockedState;
    System.Gadget.Flyout.onShow = OnEvent_ShowFlyout;
    System.Gadget.Flyout.onHide = OnEvent_HideFlyout;

    // Load all saved settings.
	LoadSettings();
}

//------------------------------------------------------------
// Nimbb_initCompleted()
// Desc: Init viewer completed.
//------------------------------------------------------------
function Nimbb_initCompleted()
{
    // Nimbb is ready.
    _Initializing = false;
    
    // Set size.
    UpdateGadgetSize();

    // Set video.
    if( _Guid != "" )
    {
        SetViewerVideo(_Guid);
    }
}

//------------------------------------------------------------
// LoadSettings()
// Desc: Load saved settings.
//------------------------------------------------------------
function LoadSettings()
{
    var oButton;

	try
	{
		// Get saved settings.
		_Guid = System.Gadget.Settings.readString("guid");
		
		// Enable button, if possible.
        oButton = _GadgetDocument.getElementById("btnShare");
		if( _Guid != "" )
		{
            oButton.disabled = "";
		}
		else
		{
		    oButton.disabled = "disabled";
		}
	}
	catch(exception)
	{
		System.Debug.outputString("LoadSettings() error: " + exception);
	}
}

//------------------------------------------------------------
// OnEvent_UndockedState()
// Desc: Undocked state.
//------------------------------------------------------------
function OnEvent_UndockedState()
{
    System.Gadget.beginTransition();
    UpdateGadgetSize();
    System.Gadget.endTransition(System.Gadget.TransitionType.none,0);
}

//------------------------------------------------------------
// OnEvent_UndockedState()
// Desc: Docked state.
//------------------------------------------------------------
function OnEvent_DockedState()
{
    System.Gadget.beginTransition();
    UpdateGadgetSize();
    System.Gadget.endTransition(System.Gadget.TransitionType.none,0);
}

//------------------------------------------------------------
// UpdateGadgetSize()
// Desc: Update gadget size based on current docking state.
//------------------------------------------------------------
function UpdateGadgetSize()
{
    if( _Initializing )
    {
        return;
    }

    var oBody = _GadgetDocument.body.style;
    var oNimbb = _GadgetDocument.getElementById("nimbbViewer");

    if (System.Gadget.docked )
    {
        oBody.width=130;
        oBody.height=118;
        oNimbb.width=130;
        oNimbb.height=98;
    }
    else
    {
        oBody.width=320;
        oBody.height=260;
        oNimbb.width=320;
        oNimbb.height=240;
    }
}

//------------------------------------------------------------
// SwitchFlyoutVisibility()
// Desc: Switch visibility state for Flyout window.
//------------------------------------------------------------
function SwitchFlyoutVisibility()
{
    System.Gadget.Flyout.show = !System.Gadget.Flyout.show;
}

//------------------------------------------------------------
// OnEvent_ShowFlyout()
// Desc: Flyout shown.
//------------------------------------------------------------
function OnEvent_ShowFlyout()
{
    var oButton = _GadgetDocument.getElementById("btnRecorder");
    oButton.innerText = LabelHide;
}

//------------------------------------------------------------
// OnEvent_HideFlyout()
// Desc: Flyout hidden.
//------------------------------------------------------------
function OnEvent_HideFlyout()
{
    var oRecorder = System.Gadget.Flyout.document.getElementById("nimbbRecorder");
    var oButton;
    var guid;
    
    try
    {   
        // Update label.
        oButton = _GadgetDocument.getElementById("btnRecorder");
        oButton.innerText = LabelShow;
    
        // Update viewer with recorded video.
        guid = oRecorder.getGuid();
        if( guid != null )
        {
            System.Gadget.Settings.writeString("guid", guid);
            SetViewerVideo(guid);
            LoadSettings();
        }
    }
    catch(exception)
    {
        System.Debug.outputString("OnEvent_HideFlyout() error: " + exception);
    }
}

//------------------------------------------------------------
// SetViewerVideo()
// Desc: Set video.
//------------------------------------------------------------
function SetViewerVideo(guid)
{
    var oViewer = _GadgetDocument.getElementById("nimbbViewer");
    
    try
    {
        oViewer.setGuid(guid);
    }
    catch(exception)
    {
        System.Debug.outputString("SetViewerVideo() error: " + exception);
    }
}

//------------------------------------------------------------
// ShareVideo()
// Desc: Open the nimbb.com site to the Share page.
//------------------------------------------------------------
function ShareVideo()
{
    var url = SHARE_URL;
    url = url.replace("[GUID]", _Guid);
    window.open(url);
}
